Iteration
:::::::::

.. toctree::
   :caption: Iteration
   :maxdepth: 2

   intro-Iteration.rst
   TheforLoop.rst
   FlowofExecutionoftheforLoop.rst
   Stringsandforloops.rst
   Listsandforloops.rst
   TheAccumulatorPattern.rst
   TraversalandtheforLoopByIndex.rst
   NestedIterationImageProcessing.rst
   WPPrintingIntermediateResults.rst
   WPNamingVariablesinForLoops.rst
   GeneralizedSequences.rst
   WPKeepingTrackofYourIteratorVariableYourIterable.rst
   Glossary.rst
   Exercises.rst
   week2a2.rst
   